from setuptools import setup


setup(
    name='nodeweb',
    version='1.0.2',
    author='zhoufangfang',
    author_email='xczff001@163.com',
    maintainer='zhoufangfang',
    maintainer_email='xczff001@163.com',
    description='这是一个可以搭建web服务器的库，使用前需安装nodejs',
    keywords=['web','nodejs'],
    py_modules=['nodeweb'],
    python_requires='>=3'
)

